package com.s3ai.corporate_app2

import com.s3ai.corporate_app2.controllers.TicketsController
import org.assertj.core.api.Assertions.assertThat
import org.junit.jupiter.api.Test
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.boot.test.context.SpringBootTest
import org.springframework.ui.ExtendedModelMap
import java.util.*


@SpringBootTest
class TicketsApiTest {
    @Autowired
    private lateinit var controller: TicketsController

    @Test
    @Throws(Exception::class)
    fun contextLoads() {
        assertThat(controller).isNotNull
    }

    @Test
    @Throws(Exception::class)
    fun shouldUpdateTicket() {
        val ticket = Ticket()
        val id = UUID.randomUUID()
        ticket.id = id
        ticket.movie = "test"
        controller.updateTicket(ticket)
        val ticketFromBase = controller.ticketService.findById(id)
        assertThat(ticketFromBase?.equals(ticket))
    }

    @Test
    @Throws(Exception::class)
    fun shouldRedirectToCreateTicketIfIdNotExists() {
        val model = ExtendedModelMap()
        val redirect = controller.getTicketEditPage(UUID.randomUUID().toString(), model)
        assertThat(redirect.equals("tickets/edit"))
        assertThat(model.getValue("action") == "Create")
    }

    @Test
    @Throws(Exception::class)
    fun shouldRedirectToEditCinemaIfIdExists() {
        val ticket = Ticket()
        val id = UUID.randomUUID()
        ticket.id = id
        ticket.movie = "test"
        controller.updateTicket(ticket)
        val model = ExtendedModelMap()
        val redirect = controller.getTicketEditPage(id.toString(), model)
        assertThat(redirect.equals("tickets/edit"))
        assertThat(model.getValue("action") == "Edit")
    }

    @Test
    @Throws(Exception::class)
    fun shouldReturnTicketsBrowsePage() {
        val ticket = Ticket()
        val id = UUID.randomUUID()
        ticket.id = id
        ticket.movie = "test"
        controller.updateTicket(ticket)
        val model = ExtendedModelMap()
        val redirect = controller.getTicketsBrowsePage(model)
        assertThat(redirect.equals("tickets/list"))
        assertThat(model.getValue("tickets")).isNotNull
    }
}